@@ -17,10 +17,10 @@ from typing import Any, Callable, Iterable, Mapping, MutableMapping, Optional, S
 from tfdsio.dataset import TFDSIOConfig, TFDSIOCorpus
 
 try:
-    import t5
-    _TFDS_DATA_DIR_OVERRIDE = t5.seqio.utils._TFDS_DATA_DIR_OVERRIDE
-    _GLOBAL_CACHE_DIRECTORIES = t5.seqio.utils._GLOBAL_CACHE_DIRECTORIES
-    Vocabulary = t5.seqio.vocabularies.Vocabulary
+    import seqio
+    _TFDS_DATA_DIR_OVERRIDE = seqio.utils._TFDS_DATA_DIR_OVERRIDE
+    _GLOBAL_CACHE_DIRECTORIES = seqio.utils._GLOBAL_CACHE_DIRECTORIES
+    Vocabulary = seqio.vocabularies.Vocabulary
 except ImportError:
     _TFDS_DATA_DIR_OVERRIDE = None
     _GLOBAL_CACHE_DIRECTORIES = []
@@ -158,7 +158,6 @@ class LazyTFDSIOLoader(object):
         builder_key = (self.name, self.data_dir)
         if builder_key not in LazyTFDSIOLoader._MEMOIZED_BUILDERS:
             LazyTFDSIOLoader._MEMOIZED_BUILDERS[builder_key] = TFDSIOCorpus(config=self._config)
-            #LazyTFDSIOLoader._MEMOIZED_BUILDERS[builder_key] = TFDSIOCorpus(data_dir=self._config.data_dir, config=self._config, version=self._config.version)
         return LazyTFDSIOLoader._MEMOIZED_BUILDERS[builder_key]
 
     @property
@@ -188,8 +187,7 @@ class LazyTFDSIOLoader(object):
         """Returns a tf.data.Dataset for the given split."""
         split = self._map_split(split)
         input_context = (tf.distribute.InputContext(num_input_pipelines=shard_info.num_shards, input_pipeline_id=shard_info.index) if shard_info else None)
-        #builder = TFDSIOCorpus(config=self._config)
-        #builder = TFDSIOCorpus(data_dir=self.data_dir, config=self._config, version=self._config.version)
+        builder = TFDSIOCorpus(config=self._config)
         if self._preprocessor:
             builder.set_preprocessor(self._preprocessor)
         builder.download_and_prepare()
